# coding: utf-8


from objectpack.actions import ObjectListWindowAction

from concentrator.changes.actions import (
    ChangesPack,
    ChangesRowsAction,
    ChangesDetailPack)

from concentrator.models import (
    ChangeDeclaration)


class LipetskChangesPack(ChangesPack):
    columns = [
        {
            'data_index': 'case_number',
            'header': u"Идентификатор изменения",
            'searchable': False,
            'sortable': True,
        }] + ChangesPack.columns

    def __init__(self):
        super(LipetskChangesPack, self).__init__()

        self.changes_rows_action = LipetskChangesRowsAction()

        self.replace_action('rows_action', self.changes_rows_action)
        self.replace_action('list_window_action', ChangesListWindowAction())


class LipetskChangesRowsAction(ChangesRowsAction):
    def _get_row(self, request, context, row):
        original_row = super(
            LipetskChangesRowsAction, self)._get_row(
            request, context, row)
        original_row['case_number'] = row.case_number

        return original_row


class LipetskChangesDetailPack(ChangesDetailPack):
    def declare_context(self, action):
        result = super(
            LipetskChangesDetailPack, self).declare_context(action)

        if action is self.list_window_action:
            result['id'] = {
                'type': 'int'}

        return result

    def get_list_window_params(self, params, request, context):
        params = super(
            LipetskChangesDetailPack, self).get_list_window_params(
            params, request, context)

        changes = ChangeDeclaration.objects.get(
            id=context.id)

        params['title'] = self.title + u" ({0})".format(
            changes.case_number)

        return params


class ChangesListWindowAction(ObjectListWindowAction):
    """
    Переопределили для задания verbose_name
    """
    verbose_name = 'Просмотр'
